#!/bin/bash
#
# source: http://ftp.gnome.org/pub/gnome/sources/
#

#------------------ Set Some Variables

soft='gnome-keyring-manager'
softversion='2.20.0'
arch="i486"
cpu="i686"
packageversion="64.1"

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="/tmp/$package"

# ----------------- Extract sources and get ready to build
cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.tgz
rm -rf $dest

cd $src

chown -R root:root .

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --mandir=/usr/man \
  --localstatedir=/var \
  --disable-static \
  --disable-schemas-install \
  --with-gconf-source="xml::/etc/gconf/gconf.xml.defaults"

make -j2 
make install DESTDIR=$dest 


find $dest | xargs file | grep -e "executable" -e "shared object" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

gzip -9 $dest/usr/man/man?/*.?

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a \
  AUTHORS ChangeLog COPYING INSTALL license_change NEWS README TODO \
  $dest/usr/doc/$soft-$softversion


# Remove help files 
rm -rf $dest/usr/share/gnome
rm -rf $dest/usr/share/omf
rm -rf $dest/usr/share/gtk-doc

mkdir -p $dest/usr/share/applications
cat << "EOF" > $dest/usr/share/applications/gnome-keyring-manager.desktop
[Desktop Entry]
Encoding=UTF-8
Name=Keyring Manager
Name[ar]=مدير حلقة المفاتيح
Name[be]=Кіраўнік зьвязкаў ключоў
Name[be@latin]=Kiraŭnik klučnikaŭ
Name[bg]=Управител на ключодържатели
Name[bn]=কি-রিং পরিচালন ব্যবস্থা
Name[bn_IN]=কি-রিং পরিচালন ব্যবস্থা
Name[ca]=Gestor de l'anell de claus
Name[cs]=Správce klíčenek
Name[cy]=Rheolwr Cylchoedd Allweddi
Name[da]=Nøgleringshåndtering
Name[de]=Schlüsselbund verwalten
Name[dz]=ལྡེ་འཁོར་འཛིན་སྐྱོང་པ།
Name[el]=Διαχείριση κωδικών
Name[en_CA]=Keyring Manager
Name[en_GB]=Keyring Manager
Name[es]=Gestor del depósito de claves
Name[et]=Võtmerõnga haldur
Name[eu]=Gako-sorten kudeatzailea
Name[fa]=مدیر دسته‌کلید
Name[fi]=Avainnippujen hallinta
Name[fr]=Gestionnaire de trousseaux
Name[gl]=Xestor de aneis de chaves
Name[gu]=કીરીંગ વ્યવસ્થાપક
Name[hi]=कीरिंग प्रबंधक
Name[hu]=Kulcstartókezelő
Name[id]=Pengelola Gantungan Kunci
Name[it]=Gestore portachiavi
Name[ja]=キーリング・マネージャ
Name[ka]=გასაღებთა აწმის მმართველი
Name[ko]=키 모음 관리자
Name[lt]=Raktinės tvarkymo programa
Name[lv]=Atslēgu saisķa pārvaldnieks
Name[mg]=Mpitantana rojom-panalahidy
Name[mk]=Менаџер за привезоци
Name[ml]=കീറിങ് മാനേജര്‍
Name[mn]=Kейринг Менежер
Name[mr]=कीरिंग व्यवस्थापक
Name[nb]=Nøkkelringhåndterer
Name[ne]=किरिङ प्रबन्धक
Name[nl]=Sleutelbossen
Name[nn]=Nøkkelringhandsamar
Name[or]=କି-ରିଙ୍ଗ ପରିଚାଳକ
Name[pa]=ਕੀਰਿੰਗ ਮੈਨੇਜਰ
Name[pl]=Menedżer bazy kluczy
Name[pt]=Gestor de Chaveiros
Name[pt_BR]=Gerenciador de Chaveiros
Name[ro]=Manager pentru keyring
Name[ru]=Управление брелоками
Name[si]=Keyring කළමණාකරු
Name[sk]=Správca zväzku kľúčov
Name[sl]=Upravitelj zbirke ključev
Name[sq]=Organizues Fjalëkalimesh
Name[sr]=Привезак за кључеве
Name[sr@Latn]=Privezak za ključeve
Name[sv]=Nyckelringshanterare
Name[ta]=விசை வளைய மேலாளர்
Name[te]=కీలకవలయం అభికర్త
Name[th]=เครื่องมือจัดการพวงกุญแจ
Name[tr]=Anahtarlık Yöneticisi
Name[uk]=Менеджер ключів
Name[vi]=Bộ quản lý Vòng chìa khóa
Name[zh_CN]=密钥环管理器
Name[zh_HK]=密碼匙圈管理員
Name[zh_TW]=鑰匙圈管理員
Comment=Manage your keyrings
Comment[ar]=أدر حلقة المفاتيح الخاصة بك
Comment[be]=Кіраваньне зьвязкамі ключоў
Comment[be@latin]=Kiruj svaimi klučnikami
Comment[bg]=Управление на вашите ключодържатели
Comment[bn]=আপনার কি-রিং পরিচালনা করুন
Comment[bn_IN]=আপনার কি-রিং পরিচালনা করুন
Comment[ca]=Gestioneu el vostre anell de claus
Comment[cs]=Spravovat vaše klíčenky
Comment[cy]=Rheoli'ch cylchoedd allweddi
Comment[da]=Håndtér dine nøgleringe
Comment[de]=Verwalten Sie Ihre Schlüsselbunde
Comment[dz]=ཁྱོད་རའི་ལྡེ་འཁོར་ འཛིན་སྐྱོང་འཐབ།
Comment[el]=Διαχείριση των κωδικών σας
Comment[en_CA]=Manage your keyrings
Comment[en_GB]=Manage your keyrings
Comment[es]=Gestione sus depósitos de claves
Comment[et]=Sinu võtmerõngaste haldamine
Comment[eu]=Kudeatu zure gako-sortak
Comment[fa]=دسته‌کلیدهای خود را مدیریت کنید
Comment[fi]=Hallitse avainnippujasi
Comment[fr]=Gère vos trousseaux
Comment[gl]=Administre os seus aneis de chaves
Comment[gu]=તમારી કીરીંગની વ્યવસ્થા કરો
Comment[hi]=अपना कीरिंग प्रबंधित करें
Comment[hu]=Kulcstartók kezelése
Comment[id]=Kelola gantungan kunci anda
Comment[it]=Gestisci i tuoi portachiavi
Comment[ja]=お使いのキーリングを管理します
Comment[ka]=საკუთარი აწმის მართვა
Comment[ko]=키 모음을 관리합니다
Comment[lt]=Tvarkyti savo raktinę
Comment[lv]=Pārvaldiet savu atslēgu saišķi
Comment[mg]=Mitantana ny rojom-panalahidinao
Comment[mk]=Справете се со привезоците
Comment[ml]=നിങ്ങളുടെ കീറിങുകള്‍ കൈകാര്യം ചെയ്യുക
Comment[mn]=Kейрингүүдийг удирдах
Comment[mr]=तुमच्या कीरिंगचे व्यवस्थापन
Comment[nb]=Håndter dine nøkkelringer
Comment[ne]=तपाईँका किरिङ प्रबन्ध गर्नुहोस्
Comment[nl]=Uw sleutelbossen (keyrings) beheren
Comment[nn]=Hald styr på nøkkelringane dine
Comment[or]=ଆପଣଙ୍କର କି-ରିଙ୍ଗକୁ ପରିଚଳନା କରନ୍ତୁ
Comment[pa]=ਆਪਣੀ ਕੀਰਿੰਗ ਸੰਭਾਲੋ
Comment[pl]=Zarządza bazą kluczy
Comment[pt]=Efectue a gestão dos seus chaveiros
Comment[pt_BR]=Gerencie seus chaveiros
Comment[ro]=Gestionează keyring-urile dumneavoastră
Comment[ru]=Управление ключами к зашифрованной информации
Comment[si]=ඔබගේ keyrings කළමාණාකරනය කරන්න
Comment[sk]=Spravovať vaše zväzky kľúčov
Comment[sl]=Upravljanje vaše zbirke ključev
Comment[sq]=Organizo fjalëkalimet e tua
Comment[sr]=Управља вашим привесцима за кључеве
Comment[sr@Latn]=Upravlja vašim privescima za ključeve
Comment[sv]=Hantera dina nyckelringar
Comment[ta]=உங்கள் விசை வளையங்களை மேலாண்மை செய்யவும்
Comment[te]=కీలకవలయాలను నిర్వహించు
Comment[th]=จัดการพวงกุญแจของคุณ
Comment[tr]=Anahtarlıklarınızı yönetin
Comment[uk]=Керує вашими в'язками ключів
Comment[vi]=Quản lý các vòng chìa khóa của bạn.
Comment[zh_CN]=管理您的密钥环
Comment[zh_HK]=管理你的密碼匙圈
Comment[zh_TW]=管理您的鑰匙圈
Exec=gnome-keyring-manager
Terminal=false
Type=Application
Icon=keyring-manager
Categories=GNOME;GTK;System;Utility;Settings;
EOF

mkdir -p $dest/install
cat << "EODESC" > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

     |-----handy-ruler-------------------------------------------------------|
gnome-keyring-manager: gnome-keyring-manager (Manager for the GNOME keyring system)
gnome-keyring-manager: 
gnome-keyring-manager: The GNOME Keyring Manager is an application for managing keyrings,
gnome-keyring-manager: in which any kind of sensitive information can be kept, mainly
gnome-keyring-manager: passwords. The default window shows 'default' keyrings with their
gnome-keyring-manager: stored items, and allows addition, removal and edition.
gnome-keyring-manager: 
gnome-keyring-manager: Secrets can be copied using drag and drop, and can also be moved
gnome-keyring-manager: between different keyrings. The manager also has creation, opening
gnome-keyring-manager: and lock/unlock features.
gnome-keyring-manager: 
gnome-keyring-manager: 

EODESC

#cat << "DOINST" > $dest/install/doinst.sh
#
#DOINST

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

# Packaging
cd $dest
makepkg -l y -c n $dest.txz
cd $buildir
rm -rf $src $dest
